@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-lambda-destinations",
-    "1.61.1",
+    "1.66.0",
     __name__[0:-6],
-    "aws-lambda-destinations@1.61.1.jsii.tgz",
+    "aws-lambda-destinations@1.66.0.jsii.tgz",
 )
 
 __all__ = [
